@@ -13,5 +13,5 @@ def test():
     assert string_cataloging.integer_to_string(y) == 'zwei'
     assert string_cataloging.integer_to_string(z) == 'drei'
     
-    assert set([string_cataloging.string_to_integer('zwei') for
-                i in range(10)]) == set([y])
\ No newline at end of file
+    assert {string_cataloging.string_to_integer('zwei') for i in xrange(10)} \
+                                                                         == {y}
\ No newline at end of file
